@@ -21,11 +21,15 @@ class IGooglefontsConfiguration(Interface):
                               required=False,
                               default="")                         
 
-  googlefontcss = schema.ASCIILine(title=_(u"label_googlefontcss", default=u'Extra css. No typos please....'),
+  googlefontcss = schema.ASCIILine(title=_(u"label_googlefontcss", default=u'Extra for css. No typos please....'),
                               description=_(u"help_googlefontcss", default=u''),
                               required=False,
                               default="")     
 
+  extracss = schema.ASCII(title=_(u"label_extracss", default=u'Extra css. Include classes and divs. No typos please....'),
+                              description=_(u"help_extracss", default=u''),
+                              required=False)    
+
 class IGooglefontsLayer(Interface):
     """
     marker interface for googlefont layer
